@@ -4,7 +4,7 @@ from . import DetectedArea
 from .DetectedArea import DetectedFace
 from . import ImageManager
 from . import Point
-from .helperFunctions import *
+from .HelperFunctions import *
 import time
 import threading
 import queue
